@@ -17,7 +17,7 @@
  *
  * @copyright &copy; 2000-2007 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: config_default.php 12302 2007-03-04 02:07:59Z jervfors $
+ * @version $Id: config_default.php 12522 2007-07-10 14:52:53Z kink $
  * @package squirrelmail
  * @subpackage config
  */
@@ -256,6 +256,26 @@ $use_smtp_tls = false;
  */
 $smtp_auth_mech = 'none';
 
+/**
+ * Custom SMTP Authentication Username
+ * 
+ * IMAP username is used if variable is set to an empty string. Variable is included in
+ * the main configuration file only in 1.4.11+ and 1.5.2+.
+ * @global string $smtp_sitewide_user
+ * @since 1.4.11
+ */
+$smtp_sitewide_user = '';
+
+/**
+ * Custom SMTP Authentication Password
+ * 
+ * IMAP password is used if variable is set to an empty string.  Variable is included in 
+ * the main configuration file in 1.4.11+ and 1.5.2+
+ * @global string $smtp_sitewide_pass
+ * @since 1.4.11
+ */
+$smtp_sitewide_pass = '';
+
 /**
  * IMAP authentication mechanism
  *
@@ -448,7 +468,7 @@ $noselect_fix_enable = false;
  *   It is a possible security hole to have a writable directory
  *   under the web server's root directory (ex: /home/httpd/html).
  *   It is possible to put the data directory anywhere you would like;
- *   it is strongly advised that it is directly web-accessible.
+ *   it is strongly advised that it is NOT directly web-accessible.
  *
  *   The path name can be absolute or relative (to the config directory).
  *   If it is relative, it must use the SM_PATH constant.
@@ -464,7 +484,7 @@ $noselect_fix_enable = false;
  *
  * @global string $data_dir
  */
-$data_dir = '/var/www/html/squirrelmail/data/';
+$data_dir = '/var/local/squirrelmail/data/';
 
 /**
  * Attachments directory
@@ -482,7 +502,7 @@ $data_dir = '/var/www/html/squirrelmail/data/';
  *    + It should probably be another directory than data_dir.
  * @global string $attachment_dir
  */
-$attachment_dir = '/var/www/html/squirrelmail/data/';
+$attachment_dir = '/var/local/squirrelmail/attach/';
 
 /**
  * Hash level used for data directory.
@@ -904,10 +924,10 @@ $motd = "";
 /**
  * To install plugins, just add elements to this array that have
  * the plugin directory name relative to the /plugins/ directory.
- * For instance, for the 'sqclock' plugin, you'd put a line like
+ * For instance, for the 'squirrelspell' plugin, you'd put a line like
  * the following.
- *    $plugins[0] = 'sqclock';
- *    $plugins[1] = 'attachment_common';
+ *    $plugins[0] = 'squirrelspell';
+ *    $plugins[1] = 'listcommands';
  */
 // Add list of enabled plugins here
 
@@ -1032,11 +1052,3 @@ $config_use_color = 2;
  */
 @include SM_PATH . 'config/config_local.php';
 
-/**
- * Make sure there are no characters after the PHP closing
- * tag below (including newline characters and whitespace).
- * Otherwise, that character will cause the headers to be
- * sent and regular output to begin, which will majorly screw
- * things up when we try to send more headers later.
- */
-?>
