@@ -5,7 +5,7 @@
  *
  * @copyright &copy; 2005-2006 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: decrypt_headers.php 11857 2006-10-07 11:58:42Z tokul $
+ * @version $Id: decrypt_headers.php 12562 2007-07-20 16:58:38Z kink $
  * @package squirrelmail
  */
 
@@ -37,14 +37,14 @@ function hex2ip($hex) {
             .hexdec(substr($hex,4,2)).'.'
             .hexdec(substr($hex,6,2));
     } elseif (strlen($hex)==32) {
-        $ret=hexdec(substr($hex,0,4)).':'
-            .hexdec(substr($hex,4,4)).':'
-            .hexdec(substr($hex,8,4)).':'
-            .hexdec(substr($hex,12,4)).':'
-            .hexdec(substr($hex,16,4)).':'
-            .hexdec(substr($hex,20,4)).':'
-            .hexdec(substr($hex,24,4)).':'
-            .hexdec(substr($hex,28,4));
+        $ret=substr($hex,0,4).':'
+            .substr($hex,4,4).':'
+            .substr($hex,8,4).':'
+            .substr($hex,12,4).':'
+            .substr($hex,16,4).':'
+            .substr($hex,20,4).':'
+            .substr($hex,24,4).':'
+            .substr($hex,28,4);
     } else {
         $ret=$hex;
     }
@@ -88,4 +88,4 @@ Check, if it is an address string: <input type="checkbox" name="ip_addr" /><br /
 <button type="submit" name="submit" value="submit">Submit</button>
 </p>
 </form>
-</body></html>
\ No newline at end of file
+</body></html>
