@@ -7,7 +7,7 @@
  *
  * @copyright &copy; 1999-2007 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: display.php 12127 2007-01-13 20:07:24Z kink $
+ * @version $Id: display.php 13103 2008-05-07 16:28:41Z pdontthink $
  * @package squirrelmail
  */
 
@@ -118,7 +118,8 @@ function load_optpage_data_display() {
     );
 
     if ($optmode != 'submit')
-       $onLoadScript = 'document.forms[0].new_js_autodetect_results.value = \'' . SMPREF_JS_ON . '\'';
+       // FIXME: our form is named "f" - why? let's use something better
+       $onLoadScript = 'document.f.new_js_autodetect_results.value = \'' . SMPREF_JS_ON . '\'';
     else
        $onLoadScript = '';
 
@@ -231,13 +232,23 @@ function load_optpage_data_display() {
 
     $optvals[SMOPT_GRP_MESSAGE][] = array(
         'name'    => 'use_javascript_addr_book',
-        'caption' => _("Addressbook Display Format"),
+        'caption' => _("Address Book Display Format"),
         'type'    => SMOPT_TYPE_STRLIST,
         'refresh' => SMOPT_REFRESH_NONE,
         'posvals' => array('1' => _("Javascript"),
                            '0' => _("HTML"))
     );
 
+    $optvals[SMOPT_GRP_MESSAGE][] = array(
+        'name'    => 'addrsrch_fullname',
+        'caption' => _("Format of Addresses Added From Address Book"),
+        'type'    => SMOPT_TYPE_STRLIST,
+        'refresh' => SMOPT_REFRESH_NONE,
+        'posvals' => array('noprefix' => _("No prefix/Address only"),
+                           'nickname' => _("Nickname and address"),
+                           'fullname' => _("Full name and address"))
+    );
+
     $optvals[SMOPT_GRP_MESSAGE][] = array(
         'name'    => 'show_html_default',
         'caption' => _("Show HTML Version by Default"),
@@ -252,13 +263,6 @@ function load_optpage_data_display() {
         'refresh' => SMOPT_REFRESH_NONE
     );
 
-    $optvals[SMOPT_GRP_MESSAGE][] = array(
-        'name'    => 'forward_cc',
-        'caption' => _("Include CCs when Forwarding Messages"),
-        'type'    => SMOPT_TYPE_BOOLEAN,
-        'refresh' => SMOPT_REFRESH_NONE
-    );
-
     $optvals[SMOPT_GRP_MESSAGE][] = array(
         'name'    => 'include_self_reply_all',
         'caption' => _("Include Me in CC when I Reply All"),
@@ -432,4 +436,3 @@ function save_option_reply_prefix($option) {
 
 }
 
-?>
