@@ -5,7 +5,7 @@
  * This script creates separate page, that allows to review and modify
  * SquirrelMail configuration file.
  *
- * @version $Id: options.php 10633 2006-02-03 22:27:56Z jervfors $
+ * @version $Id: options.php 12538 2007-07-14 19:04:00Z kink $
  * @author Philippe Mingo
  * @copyright (c) 1999-2006 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
@@ -13,6 +13,9 @@
  * @subpackage administrator
  */
 
+/** This is the administrator_options page */
+define('PAGE_NAME', 'administrator_options');
+
 /**
  * parse the config file
  *
@@ -164,6 +167,7 @@ function change_to_rel_path($old_path) {
  *     ../images/logo.gif      --> SM_PATH . 'images/logo.gif'
  *     images/logo.gif         --> SM_PATH . 'config/images/logo.gif'
  *     /absolute/path/logo.gif --> '/absolute/path/logo.gif'
+ *     C:/absolute/win/path    --> 'C:/absolute/win/path'
  *     http://whatever/        --> 'http://whatever'
  *  
  * @param string $old_path path that has to be converted
@@ -173,7 +177,8 @@ function change_to_rel_path($old_path) {
 function change_to_sm_path($old_path) {
     if ( $old_path === '' || $old_path == "''" ) {
         return "''";
-    } elseif ( preg_match("/^(\/|http)/", $old_path) ) {
+    } elseif ( preg_match("/^(\/|http)/", $old_path) ||
+        substr($old_path,1,2) == ':/' ) {
         return "'" . $old_path . "'";
     } elseif ( preg_match("/^(\$|SM_PATH)/", $old_path) ) {
         return $old_path;
@@ -631,4 +636,4 @@ if ( $fp = @fopen( $cfgfile, 'w' ) ) {
          '</big></p>';
 }
 ?>
-</body></html>
\ No newline at end of file
+</body></html>
