@@ -9,7 +9,7 @@
  * @copyright Copyright &copy; 2002 Marc Groot Koerkamp, The Netherlands
  * @copyright Copyright &copy; 2004-2006 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: message_details_main.php 10633 2006-02-03 22:27:56Z jervfors $
+ * @version $Id: message_details_main.php 12687 2007-09-15 01:18:09Z pdontthink $
  * @package plugins
  * @subpackage message_details
  */
@@ -27,13 +27,17 @@ displayHtmlHeader( _("Message Details"), '', FALSE );
 
 sqgetGlobalVar('mailbox', $mailbox, SQ_GET);
 sqgetGlobalVar('passed_id', $passed_id, SQ_GET);
+if (!sqgetGlobalVar('passed_ent_id', $passed_ent_id, SQ_GET))
+    $passed_ent_id = 0;
 
 echo "<frameset rows=\"60, *\" noresize border=\"0\">\n";
 echo '<frame src="message_details_top.php?mailbox=' 
-    . urlencode($mailbox) .'&amp;passed_id=' . "$passed_id"
+    . urlencode($mailbox) .'&amp;passed_id=' . $passed_id
+    . '&amp;passed_ent_id=' . $passed_ent_id
     . '" name="top_frame" scrolling="off">';
 echo '<frame src="message_details_bottom.php?mailbox=' 
-    . urlencode($mailbox) .'&amp;passed_id=' . "$passed_id" 
+    . urlencode($mailbox) .'&amp;passed_id=' . $passed_id 
+    . '&amp;passed_ent_id=' . $passed_ent_id
     . '" name="bottom_frame">';
 echo '</frameset>'."\n"."</html>\n";
-?>
\ No newline at end of file
+?>
