@@ -5,7 +5,7 @@
     **  Copyright (c) 1999-2006 The SquirrelMail Project Team
     **  Licensed under the GNU GPL. For full terms see the file COPYING.
     **  
-    **  $Id: spamcop.php 11393 2006-07-13 10:13:23Z tokul $                                                         
+    **  $Id: spamcop.php 12601 2007-08-27 03:06:10Z pdontthink $                                                         
     **/
 
 define('SM_PATH','../../');
@@ -132,34 +132,34 @@ echo "</p>";
 <table align="center" width="75%" border="0" cellpadding="0" cellspacing="0">
 <tr>
 <td align="left" valign="top">
-<?PHP if (isset($js_web) && $js_web) {
+<?php if (isset($js_web) && $js_web) {
   echo "<form method=\"post\" action=\"javascript:return false\">\n";
   echo '<input type="button" value="' . _("Close Window") . "\" onClick=\"window.close(); return true;\" />\n";
 } else {
-   ?><form method="post" action="../../src/right_main.php">
-  <input type="hidden" name="mailbox" value="<?PHP echo htmlspecialchars($mailbox) ?>" />
-  <input type="hidden" name="startMessage" value="<?PHP echo htmlspecialchars($startMessage) ?>" />
-   <?PHP
+   ?><form method="post" action="<?php echo sqm_baseuri(); ?>src/right_main.php">
+  <input type="hidden" name="mailbox" value="<?php echo htmlspecialchars($mailbox) ?>" />
+  <input type="hidden" name="startMessage" value="<?php echo htmlspecialchars($startMessage) ?>" />
+   <?php
   echo '<input type="submit" value="' . _("Cancel / Done") . "\" />\n";
 }
   ?></form>
 </td>
 <td align="right" valign="top">
-<?PHP if ($spamcop_method == 'thorough_email' ||
+<?php if ($spamcop_method == 'thorough_email' ||
           $spamcop_method == 'quick_email') {
    if ($spamcop_method == 'thorough_email')
       $report_email = 'submit.' . $spamcop_id . '@spam.spamcop.net';
    else
       $report_email = 'quick.' . $spamcop_id . '@spam.spamcop.net';
-   $form_action = SM_PATH . 'src/compose.php';
-?>  <form method="post" action="<?PHP echo $form_action?>">
-  <input type="hidden" name="mailbox" value="<?PHP echo htmlspecialchars($mailbox) ?>" />
-  <input type="hidden" name="spamcop_is_composing" value="<?PHP echo htmlspecialchars($passed_id) ?>" />
-  <input type="hidden" name="send_to" value="<?PHP echo htmlspecialchars($report_email)?>" />
+   $form_action = sqm_baseuri() . 'src/compose.php';
+?>  <form method="post" action="<?php echo $form_action?>">
+  <input type="hidden" name="mailbox" value="<?php echo htmlspecialchars($mailbox) ?>" />
+  <input type="hidden" name="spamcop_is_composing" value="<?php echo htmlspecialchars($passed_id) ?>" />
+  <input type="hidden" name="send_to" value="<?php echo htmlspecialchars($report_email)?>" />
   <input type="hidden" name="subject" value="reply anyway" />
   <input type="hidden" name="identity" value="0" />
-  <input type="hidden" name="session" value="<?PHP echo $session?>" />
-<?PHP  
+  <input type="hidden" name="session" value="<?php echo $session?>" />
+<?php  
   echo '<input type="submit" name="send" value="' . _("Send Spam Report") . "\" />\n";
  } else {
    $spam_message = mime_fetch_body ($imap_stream, $passed_id, $passed_ent_id, 50000);
@@ -170,19 +170,19 @@ echo "</p>";
    }
    if (isset($js_web) && $js_web) {
 ?>  <form method="post" action="http://members.spamcop.net/sc" name="submitspam"
-    enctype="multipart/form-data"><?PHP
+    enctype="multipart/form-data"><?php
    } else {
 ?>  <form method="post" action="http://members.spamcop.net/sc" name="submitspam"
-    enctype="multipart/form-data" target="_top"><?PHP
+    enctype="multipart/form-data" target="_top"><?php
    } ?>
   <input type="hidden" name="action" value="submit" />
   <input type="hidden" name="oldverbose" value="1" />
-  <input type="hidden" name="spam" value="<?PHP echo htmlspecialchars($spam_message); ?>" />
-<?PHP
+  <input type="hidden" name="spam" value="<?php echo htmlspecialchars($spam_message); ?>" />
+<?php
   echo '<input type="submit" name="x1" value="' . _("Send Spam Report") . "\" />";
  }
 ?>
 </form>
 </td></tr>
 </table>
-</body></html>
\ No newline at end of file
+</body></html>
