@@ -8,10 +8,13 @@
  *
  * @copyright &copy; 1999-2007 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: left_main.php 12319 2007-03-06 16:03:45Z kink $
+ * @version $Id: left_main.php 12537 2007-07-14 18:34:04Z kink $
  * @package squirrelmail
  */
 
+/** This is the left_main page */
+define('PAGE_NAME', 'left_main');
+
 /**
  * Path for SquirrelMail required files.
  * @ignore
@@ -307,9 +310,9 @@ $imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 1
  */
 if (isset($left_refresh) && ($left_refresh != '') &&
     !stristr($left_refresh, 'none')){
-    $xtra =  "\n<meta http-equiv=\"Expires\" content=\"Thu, 01 Dec 1994 16:00:00 GMT\" />\n" .
-             "<meta http-equiv=\"Pragma\" content=\"no-cache\" />\n".
-             "<meta http-equiv=\"REFRESH\" content=\"$left_refresh;URL=left_main.php\" />\n";
+    $xtra =  "\n<meta http-equiv=\"Expires\" content=\"Thu, 01 Dec 1994 16:00:00 GMT\">\n" .
+             "<meta http-equiv=\"Pragma\" content=\"no-cache\">\n".
+             "<meta http-equiv=\"REFRESH\" content=\"$left_refresh;URL=left_main.php\">\n";
 } else {
     $xtra = '';
 }
