@@ -9,10 +9,13 @@
  *
  * @copyright &copy; 1999-2007 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: webmail.php 12352 2007-03-28 05:09:33Z jangliss $
+ * @version $Id: webmail.php 12767 2007-11-15 06:31:24Z jangliss $
  * @package squirrelmail
  */
 
+/** This is the webmail page */
+define('PAGE_NAME', 'webmail');
+
 /**
  * Path for SquirrelMail required files.
  * @ignore
@@ -25,8 +28,6 @@ require_once(SM_PATH . 'functions/imap.php');
 
 $base_uri = sqm_baseuri();
 
-sqsession_is_active();
-
 sqgetGlobalVar('username', $username, SQ_SESSION);
 sqgetGlobalVar('delimiter', $delimiter, SQ_SESSION);
 sqgetGlobalVar('onetimepad', $onetimepad, SQ_SESSION);
@@ -51,6 +52,10 @@ if(sqgetGlobalVar('mailtodata', $mailtodata)) {
 
 is_logged_in();
 
+// this value may be changed by a plugin, but initialize
+// it first to avoid register_globals headaches
+//
+$right_frame_url = '';
 do_hook('webmail_top');
 
 /**
@@ -65,7 +70,7 @@ if ($my_language != $squirrelmail_language) {
     setcookie('squirrelmail_language', $my_language, time()+2592000, $base_uri);
 }
 
-set_up_language(getPref($data_dir, $username, 'language'));
+set_up_language($my_language);
 
 $output = "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Frameset//EN\">\n".
           "<html><head>\n" .
@@ -118,6 +123,11 @@ else {
  *
  * The test for // should catch any attempt to include off-site webpages into
  * our frameset.
+ *
+ * Note that plugins are allowed to completely and freely override the URI
+ * used for the "right" (content) frame, and they do so by modifying the 
+ * global variable $right_frame_url.
+ *
  */
 
 if (empty($right_frame) || (strpos(urldecode($right_frame), '//') !== false)) {
@@ -130,36 +140,38 @@ if ( strpos($right_frame,'?') ) {
     $right_frame_file = $right_frame;
 }
 
-switch($right_frame_file) {
-    case 'right_main.php':
-        $right_frame_url = "right_main.php?mailbox=".urlencode($mailbox)
-                       . (!empty($sort)?"&amp;sort=$sort":'')
-                       . (!empty($startMessage)?"&amp;startMessage=$startMessage":'');
-        break;
-    case 'options.php':
-        $right_frame_url = 'options.php';
-        break;
-    case 'folders.php':
-        $right_frame_url = 'folders.php';
-        break;
-    case 'compose.php':
-        $right_frame_url = 'compose.php?' . $mailtourl;
-        break;
-    case '':
-        $right_frame_url = 'right_main.php';
-        break;
-    default:
-        $right_frame_url =  urlencode($right_frame);
-        break;
+if (empty($right_frame_url)) {
+    switch($right_frame_file) {
+        case 'right_main.php':
+            $right_frame_url = "right_main.php?mailbox=".urlencode($mailbox)
+                           . (!empty($sort)?"&amp;sort=$sort":'')
+                           . (!empty($startMessage)?"&amp;startMessage=$startMessage":'');
+            break;
+        case 'options.php':
+            $right_frame_url = 'options.php';
+            break;
+        case 'folders.php':
+            $right_frame_url = 'folders.php';
+            break;
+        case 'compose.php':
+            $right_frame_url = 'compose.php?' . $mailtourl;
+            break;
+        case '':
+            $right_frame_url = 'right_main.php';
+            break;
+        default:
+            $right_frame_url =  urlencode($right_frame);
+            break;
+    } 
 } 
 
 if ($location_of_bar == 'right') {
-    $output .= "<frame src=\"$right_frame_url\" name=\"right\" frameborder=\"1\" />\n" .
-               "<frame src=\"left_main.php\" name=\"left\" frameborder=\"1\" />\n";
+    $output .= "<frame src=\"$right_frame_url\" name=\"right\" frameborder=\"1\">\n" .
+               "<frame src=\"left_main.php\" name=\"left\" frameborder=\"1\">\n";
 }
 else {
-    $output .= "<frame src=\"left_main.php\" name=\"left\" frameborder=\"1\" />\n".
-               "<frame src=\"$right_frame_url\" name=\"right\" frameborder=\"1\" />\n";
+    $output .= "<frame src=\"left_main.php\" name=\"left\" frameborder=\"1\">\n".
+               "<frame src=\"$right_frame_url\" name=\"right\" frameborder=\"1\">\n";
 }
 $ret = concat_hook_function('webmail_bottom', $output);
 if($ret != '') {
